@@ -4,6 +4,8 @@
 # @Author  : bruce
 # @desc    :
 """
+import sys
+
 from api_test_ez.ez import get_config, Log
 from api_test_ez.ez.decorator import singleton
 from api_test_ez.project.configs import Configs
@@ -50,8 +52,8 @@ def init_project(project='default'):
     if cfg.has_option('settings', project):
         project_settings_path = cfg.get('settings', project)
         os.environ[ENV_EZ_SETTINGS_MODULE] = project_settings_path
-        os.environ[ENV_EZ_PROJECT_DIR] = os.path.abspath(
-            os.path.join(project_cfg_path + '/../', *project_settings_path.split('.')[:-1]))
+        os.environ[ENV_EZ_PROJECT_DIR] = os.path.abspath(os.path.dirname(project_settings_path))
+        sys.path.append(os.environ[ENV_EZ_PROJECT_DIR])
 
 
 def get_ez_settings():
